@@ -1,3 +1,3 @@
 """Related to configuration."""
 
-__all__ = ['config', 'log']
+__all__ = ['config']
