@@ -1,7 +1,7 @@
 #!/usr/bin/env python2.6
 # -*- coding: utf-8 -*-
 #
-# Copyright 2009-2010, the 'Scripy' Authors
+# Copyright 2009-2010, the Scripy Authors
 # Use of this source code is governed by the ISC License (LICENSE file).
 
 """
@@ -11,10 +11,18 @@ load_yaml - load YAML file.
 __all__ = ['load_yaml']
 
 import yaml
+import yamlog
+# In order to use LibYAML based parser and emitter, use the classes CParser
+# and CEmitter.
+try:
+    from yaml import CLoader as Loader
+    from yaml import CDumper as Dumper
+except ImportError:
+    from yaml import Loader, Dumper
 
-from .. import (shell, system)
+from .. import system
 
-_log = shell.logger(__name__)
+_log = yamlog.logger(__name__)
 
 
 def load_yaml(filename):
@@ -41,8 +49,8 @@ def load_yaml(filename):
 
     """
     try:
-        f = file(filename, 'r')
-        config = yaml.load(f)  #! safe_load ?
+        f = open(filename, 'r')
+        config = yaml.load_all(f, Loader=Loader)
     except yaml.YAMLError as err:
         f.close()
         _log.error('can not load YAML file')
